pub(crate) trait AffineExt {
// Required methods
fn has_skew(&self) -> bool;
fn has_vertical_skew(&self) -> bool;
fn is_positive_uniform_scale_without_skew(&self) -> bool;
fn is_positive_uniform_scale_without_vertical_skew(&self) -> bool;
fn has_non_unit_skew_or_scale(&self) -> bool;
}Required Methods
Sourcefn has_vertical_skew(&self) -> bool
fn has_vertical_skew(&self) -> bool
Whether the transform has a vertical skew.
Sourcefn is_positive_uniform_scale_without_skew(&self) -> bool
fn is_positive_uniform_scale_without_skew(&self) -> bool
Whether the transform has positive, uniform scaling factors and no skew.
Sourcefn is_positive_uniform_scale_without_vertical_skew(&self) -> bool
fn is_positive_uniform_scale_without_vertical_skew(&self) -> bool
Whether the transform has positive, uniform scaling factors and no vertical skew.
Sourcefn has_non_unit_skew_or_scale(&self) -> bool
fn has_non_unit_skew_or_scale(&self) -> bool
Whether the transform has non-unit scale or skew.
Note that negative scales (i.e. -1.0) are explicitly allowed.
Implementations on Foreign Types
Sourceimpl AffineExt for Affine
impl AffineExt for Affine
Sourcefn has_vertical_skew(&self) -> bool
fn has_vertical_skew(&self) -> bool
Whether the transform has a vertical skew.